import { CommonModule } from '@angular/common';
import { Inject, Component, ViewEncapsulation, Injectable, NgModule } from '@angular/core';
import { NT_MODAL_DATA, NtModal, NtModalModule } from '@ng-tangram/components/modal';
import { NtSwitchModule } from '@ng-tangram/components/switch';
import { Subject } from 'rxjs';
import { takeUntil } from 'rxjs/operators';

var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
let NtColumnSettingComponent = class NtColumnSettingComponent {
    constructor(data) {
        this.data = data;
        this._destroy = new Subject();
        this._displayedColumnChanges = new Subject();
        this.displayedColumns = [];
        this.columns = this.data.columns;
        this.columnNames = this.columns.map(col => col.name);
        this.displayedColumns = this.data.displayedColumns;
    }
    ngOnDestroy() {
        this._destroy.next();
        this._destroy.complete();
    }
    displayedColumnChanges() {
        return this._displayedColumnChanges
            .asObservable()
            .pipe(takeUntil(this._destroy));
    }
    _onChange(change, columnName) {
        if (change.checked) {
            this.displayedColumns.push(columnName);
        }
        else {
            const index = this.displayedColumns.indexOf(columnName);
            this.displayedColumns.splice(index, 1);
        }
        const sortedColumns = this.columnNames.filter(name => this.displayedColumns.includes(name));
        this._displayedColumnChanges.next(sortedColumns);
    }
    _trackColumnChecked(columnName) {
        return this.displayedColumns.includes(columnName);
    }
};
NtColumnSettingComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [NT_MODAL_DATA,] }] }
];
NtColumnSettingComponent = __decorate([
    Component({
        template: "<nt-modal-header>\u6570\u636E\u5217\u663E\u793A\u8BBE\u7F6E</nt-modal-header>\n<nt-modal-body class=\"padding-0\">\n  <div class=\"nt-column-setting\">\n    <div class=\"nt-column-setting-menu\">\n      <div class=\"nt-column-setting-item\"\n        [class.disabled]=\"!col.optional\"\n        *ngFor=\"let col of columns\">\n        <a class=\"nt-column-setting-label\">{{ col.label }}</a>\n        <span class=\"nt-column-setting-control\">\n          <nt-switch class=\"nt-column-switch large\"\n            [checked]=\"_trackColumnChecked(col.name)\"\n            (change)=\"_onChange($event, col.name)\"\n            [disabled]=\"!col.optional\"\n            circle>\n          </nt-switch>\n        </span>\n      </div>\n    </div>\n  </div>\n</nt-modal-body>\n",
        encapsulation: ViewEncapsulation.None
    }),
    __param(0, Inject(NT_MODAL_DATA))
], NtColumnSettingComponent);

var __decorate$1 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let MzColumnSetting = class MzColumnSetting {
    constructor(modal) {
        this.modal = modal;
        this._defaultModalConfig = {
            width: '460px',
            maxWidth: '90vw',
            maxHeight: '90vh',
            backdropClass: 'light-backdrop'
        };
    }
    openAndTrackChanges(columns, displayedColumns) {
        const data = { columns, displayedColumns };
        const modalConfig = Object.assign(Object.assign({}, this._defaultModalConfig), { data });
        const modalRef = this.modal.open(NtColumnSettingComponent, modalConfig);
        return modalRef.componentInstance.displayedColumnChanges();
    }
};
MzColumnSetting.ctorParameters = () => [
    { type: NtModal }
];
MzColumnSetting = __decorate$1([
    Injectable()
], MzColumnSetting);

var __decorate$2 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let NtColumnSettingModule = class NtColumnSettingModule {
};
NtColumnSettingModule = __decorate$2([
    NgModule({
        imports: [
            CommonModule,
            NtModalModule,
            NtSwitchModule
        ],
        entryComponents: [NtColumnSettingComponent],
        declarations: [NtColumnSettingComponent],
        providers: [MzColumnSetting],
    })
], NtColumnSettingModule);

export { MzColumnSetting, NtColumnSettingComponent, NtColumnSettingModule };
//# sourceMappingURL=columnController.js.map
