import { InjectionToken, Inject, Injectable, Component, ViewEncapsulation, ChangeDetectionStrategy, ChangeDetectorRef, Input, NgModule } from '@angular/core';
import { OverlayModule } from '@angular/cdk/overlay';
import { CommonModule } from '@angular/common';
import { NavigationEnd, ActivatedRoute, Router, RouterModule } from '@angular/router';
import { NtOverlayModule } from '@ng-tangram/components/overlay';
import { Subject, BehaviorSubject, merge } from 'rxjs';
import { takeUntil, filter, switchMap } from 'rxjs/operators';
import { coerceBooleanProperty } from '@angular/cdk/coercion';

var NtNavUrlTreeStrategy;
(function (NtNavUrlTreeStrategy) {
    NtNavUrlTreeStrategy[NtNavUrlTreeStrategy["Integrity"] = 0] = "Integrity";
    NtNavUrlTreeStrategy[NtNavUrlTreeStrategy["OnlyParents"] = 1] = "OnlyParents";
})(NtNavUrlTreeStrategy || (NtNavUrlTreeStrategy = {}));
const NT_NAV_CONFIG = new InjectionToken('nt-nav-config');

const RESOLVE_TITLE_PLACEHOLDER = /^resolve::/;
function resolveTitle(snapshot, title) {
    var _a;
    if (RESOLVE_TITLE_PLACEHOLDER.test(title)) {
        const paths = title.replace(RESOLVE_TITLE_PLACEHOLDER, '').split('.');
        const key = paths.shift();
        try {
            if (key && ((_a = snapshot.data) === null || _a === void 0 ? void 0 : _a.hasOwnProperty(key))) {
                const data = snapshot.data[key];
                let path = paths.shift();
                let result = path ? data[path] : null;
                while (paths.length > 0 && result instanceof Object) {
                    path = paths.shift();
                    result = path ? result[path] : null;
                }
                return result;
            }
            return key || '';
        }
        catch (_b) { }
    }
    return title;
}

var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
const NT_NAV_MENUS = new InjectionToken('nt-nav-menus');
let NtNavigationAdapter = class NtNavigationAdapter {
    constructor(route, router, config, menus) {
        this.route = route;
        this.router = router;
        this.config = config;
        this.destroy = new Subject();
        this.menus = new BehaviorSubject([]);
        this.activatedUrlTree = new BehaviorSubject([]);
        this.activeUrl = new BehaviorSubject({});
        this.menus.next(menus);
        router.events
            .pipe(takeUntil(this.destroy), filter(event => event instanceof NavigationEnd))
            .subscribe(() => this.buildUrlTree(this.route));
    }
    ngOnDestroy() {
        this.destroy.next();
        this.destroy.complete();
    }
    getRouteMenus() {
        return this.menus.asObservable();
    }
    buildUrlTree(route) {
        let url = [];
        const tree = [];
        while (route.firstChild) {
            route = route.firstChild;
            const snapshot = route.snapshot;
            if (snapshot.data && snapshot.data.title && snapshot.url.length > 0) {
                let data = snapshot.data, title;
                title = resolveTitle(snapshot, data.title);
                url = url.concat(snapshot.url.map(segment => segment.path));
                tree.push({ title, url, icon: data.icon });
            }
        }
        this.activeUrl.next(tree[tree.length - 1]);
        if (this.config.urlTreeStrategy === NtNavUrlTreeStrategy.OnlyParents) {
            tree.splice(tree.length - 1, 1);
        }
        this.activatedUrlTree.next(tree);
    }
};
NtNavigationAdapter.ctorParameters = () => [
    { type: ActivatedRoute },
    { type: Router },
    { type: undefined, decorators: [{ type: Inject, args: [NT_NAV_CONFIG,] }] },
    { type: Array, decorators: [{ type: Inject, args: [NT_NAV_MENUS,] }] }
];
NtNavigationAdapter = __decorate([
    Injectable(),
    __param(2, Inject(NT_NAV_CONFIG)),
    __param(3, Inject(NT_NAV_MENUS))
], NtNavigationAdapter);

var __decorate$1 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let NtNavBreadcrumbsComponent = class NtNavBreadcrumbsComponent {
    constructor(navAdapter) {
        this.navAdapter = navAdapter;
        this.activeUrl$ = this.navAdapter.activeUrl.asObservable();
    }
};
NtNavBreadcrumbsComponent.ctorParameters = () => [
    { type: NtNavigationAdapter }
];
NtNavBreadcrumbsComponent = __decorate$1([
    Component({
        selector: 'nt-nav-breadcrumbs',
        template: "<ng-container *ngIf=\"activeUrl$ | async as activeUrl\">\n  <span class=\"nt-nav-activated-icon {{ activeUrl.icon }}\"></span>\n  <span class=\"nt-nav-activated-title\">{{ activeUrl.title }}</span>\n  <ul class=\"nt-nav-breadcrumbs-menu\">\n    <li *ngFor=\"let item of navAdapter.activatedUrlTree | async; let $index = index;\">\n      <a [routerLink]=\"['./'].concat(item.url)\">\n        {{ item.title }}\n      </a>\n    </li>\n  </ul>\n</ng-container>\n",
        encapsulation: ViewEncapsulation.None,
        changeDetection: ChangeDetectionStrategy.OnPush,
        host: {
            'class': 'nt-nav-breadcrumbs'
        }
    })
], NtNavBreadcrumbsComponent);

class NtNavController {
    constructor(changeDetectorRef, navAdapter) {
        this.changeDetectorRef = changeDetectorRef;
        this.navAdapter = navAdapter;
        this.destroy = new Subject();
        this.routeMenusUpdate = new Subject();
        merge(this.routeMenusUpdate, navAdapter.getRouteMenus()).pipe(switchMap(() => navAdapter.getRouteMenus()), takeUntil(this.destroy)).subscribe(menus => {
            this._routeMenus = this._filterRouteMenus(menus);
            this._checkActivatedMenu();
            this.changeDetectorRef.markForCheck();
        });
        this.navAdapter.activatedUrlTree
            .pipe(takeUntil(this.destroy), filter(tree => tree.length > 0))
            .subscribe(() => {
            this._checkActivatedMenu();
            this.changeDetectorRef.markForCheck();
        });
    }
    _checkActivatedMenu() {
        const currentTree = this.navAdapter.activatedUrlTree.value;
        if (currentTree.length > 0) {
            const moduleName = currentTree[0].url.join('/');
            const activated = this._routeMenus.find(menu => menu.path === moduleName);
            activated && (activated.folded = true);
        }
    }
    _filterRouteMenus(menus) {
        if (typeof this.filter !== 'function') {
            return menus;
        }
        const parents = menus.filter(parent => {
            if (parent.children && parent.children.length > 0) {
                return true;
            }
            else {
                return this.filter(parent);
            }
        });
        const value = parents.map(parent => {
            const copy = Object.assign({}, parent);
            if (copy.children) {
                copy.children = copy.children.filter(child => this.filter(child));
            }
            return copy;
        });
        const result = [];
        value.forEach((menuItem) => {
            if (!menuItem.children || (menuItem.children && menuItem.children.length > 0)) {
                result.push(Object.assign({}, menuItem));
            }
        });
        return result;
    }
}

var __decorate$2 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let NtNavSidebarComponent = class NtNavSidebarComponent extends NtNavController {
    constructor(changeDetectorRef, navAdapter) {
        super(changeDetectorRef, navAdapter);
        this._dropdown = false;
        this._baseUrl = navAdapter.config.baseUrl || './';
    }
    get dropdown() { return this._dropdown; }
    set dropdown(value) {
        this._dropdown = coerceBooleanProperty(value);
    }
    get filter() { return this._filter; }
    set filter(value) {
        if (value) {
            this._filter = value;
            this.routeMenusUpdate.next();
        }
    }
};
NtNavSidebarComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: NtNavigationAdapter }
];
__decorate$2([
    Input()
], NtNavSidebarComponent.prototype, "dropdown", null);
__decorate$2([
    Input()
], NtNavSidebarComponent.prototype, "filter", null);
__decorate$2([
    Input()
], NtNavSidebarComponent.prototype, "title", void 0);
__decorate$2([
    Input()
], NtNavSidebarComponent.prototype, "logo", void 0);
NtNavSidebarComponent = __decorate$2([
    Component({
        selector: 'nt-nav-sidebar',
        template: "\n<!-- <ng-content select=\"nt-nav-sidebar-logo\"></ng-content> -->\n<div class=\"nt-nav-sidebar-brand\">\n  <img class=\"nt-nav-sidebar-logo\" [src]=\"logo\">\n  <span class=\"nt-nav-sidebar-title\" *ngIf=\"!dropdown\">{{ title }}</span>\n</div>\n\n<ul class=\"nt-nav-sidebar-root-menu\">\n  <li *ngFor=\"let parent of _routeMenus\"\n    routerLinkActive=\"active\"\n    [class.folded]=\"parent.folded\"\n    [class.has-children]=\"parent.children\">\n\n    <ng-container *ngIf=\"!dropdown else dropdownMode\">\n      <a *ngIf=\"!parent.children else hasChildrenMenus\" [routerLink]=\"[_baseUrl, parent.path]\">\n        <i [class]=\"parent.data['icon']\"></i>\n        <span class=\"nt-nav-sidebar-title\">{{ parent.data['title'] }}</span>\n      </a>\n      <ng-template #hasChildrenMenus>\n        <a (click)=\"parent.folded = !parent.folded\">\n          <i [class]=\"parent.data['icon']\"></i>\n          <span class=\"nt-nav-sidebar-title\">{{ parent.data['title'] }}</span>\n        </a>\n        <ul class=\"nt-nav-sidebar-nested-menu\">\n          <li *ngFor=\"let child of parent.children\" routerLinkActive=\"active\">\n            <a [routerLink]=\"[_baseUrl, parent.path, child.path]\">\n              <span class=\"nt-nav-sidebar-title\">{{ child.data['title'] }}</span>\n            </a>\n          </li>\n        </ul>\n      </ng-template>\n    </ng-container>\n\n    <ng-template #dropdownMode>\n      <ng-container *ngIf=\"!parent.children else hasChildrenMenus\">\n        <a #origin=\"cdkOverlayOrigin\"\n        cdkOverlayOrigin\n        (mouseenter)=\"overlay.markOpen()\"\n        (mouseleave)=\"overlay.markClose()\"\n        [routerLink]=\"[_baseUrl, parent.path]\">\n          <i [class]=\"parent.data['icon']\"></i>\n          <span class=\"nt-nav-sidebar-title\">{{ parent.data['title'] }}</span>\n\n          <nt-overlay\n            #overlay\n            overlayClass=\"nt-nav-dropdown-overlay\"\n            [origin]=\"origin\"\n            position=\"rightTop\"\n            [arrow]=\"true\"\n            (overlayEnter)=\"overlay.markOpen()\"\n            (overlayLeave)=\"overlay.markClose()\">\n            <div class=\"nt-nav-dropdown-pane\">\n              <div class=\"nt-nav-dropdown-title\">{{ parent.data['title'] }}</div>\n            </div>\n          </nt-overlay>\n        </a>\n      </ng-container>\n      <ng-template #hasChildrenMenus>\n        <a #origin=\"cdkOverlayOrigin\"\n          cdkOverlayOrigin\n          (mouseenter)=\"overlay.markOpen()\"\n          (mouseleave)=\"overlay.markClose()\">\n          <i [class]=\"parent.data['icon']\"></i>\n          <span class=\"nt-nav-sidebar-title\">{{ parent.data['title'] }}</span>\n          <nt-overlay\n            #overlay\n            overlayClass=\"nt-nav-dropdown-overlay\"\n            [origin]=\"origin\"\n            position=\"rightTop\"\n            [arrow]=\"true\"\n            (overlayEnter)=\"overlay.markOpen()\"\n            (overlayLeave)=\"overlay.markClose()\">\n            <div class=\"nt-nav-dropdown-pane\">\n              <div class=\"nt-nav-dropdown-title\">{{ parent.data['title'] }}</div>\n              <ul class=\"nt-nav-dropdown-menu\">\n                <li *ngFor=\"let child of parent.children\" routerLinkActive=\"active\">\n                  <a [routerLink]=\"[_baseUrl, parent.path, child.path]\">\n                    <span>{{ child.data['title'] }}</span>\n                  </a>\n                </li>\n              </ul>\n            </div>\n          </nt-overlay>\n        </a>\n      </ng-template>\n    </ng-template>\n  </li>\n</ul>\n\n",
        encapsulation: ViewEncapsulation.None,
        changeDetection: ChangeDetectionStrategy.OnPush,
        host: {
            'class': 'nt-nav-sidebar',
            '[class.dropdown-mode]': 'dropdown'
        }
    })
], NtNavSidebarComponent);

var __decorate$3 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let NtNavTopbarComponent = class NtNavTopbarComponent extends NtNavController {
    constructor(changeDetectorRef, navAdapter) {
        super(changeDetectorRef, navAdapter);
        this._baseUrl = navAdapter.config.baseUrl || './';
    }
    get filter() { return this._filter; }
    set filter(value) {
        if (value) {
            this._filter = value;
            this.routeMenusUpdate.next();
        }
    }
};
NtNavTopbarComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: NtNavigationAdapter }
];
__decorate$3([
    Input()
], NtNavTopbarComponent.prototype, "filter", null);
NtNavTopbarComponent = __decorate$3([
    Component({
        selector: 'nt-nav-topbar',
        template: "<ul class=\"nt-nav-topbar-menu\">\n  <li *ngFor=\"let parent of _routeMenus\" routerLinkActive=\"active\" class=\"nt-nav-topbar-menu-item\">\n    <a [routerLink]=\"[_baseUrl, parent.path]\">\n      <span [class]=\"parent.data.icon\"></span>&nbsp;&nbsp;{{ parent.data.title }}\n    </a>\n  </li>\n</ul>\n",
        encapsulation: ViewEncapsulation.None,
        changeDetection: ChangeDetectionStrategy.OnPush,
        host: {
            'class': 'nt-nav-topbar'
        }
    })
], NtNavTopbarComponent);

var __decorate$4 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var NtNavModule_1;
let NtNavModule = NtNavModule_1 = class NtNavModule {
    static forRoot(config) {
        return {
            ngModule: NtNavModule_1,
            providers: [
                { provide: NT_NAV_CONFIG, useValue: config }
            ]
        };
    }
};
NtNavModule = NtNavModule_1 = __decorate$4([
    NgModule({
        imports: [
            CommonModule,
            RouterModule,
            OverlayModule,
            NtOverlayModule,
        ],
        exports: [
            NtNavSidebarComponent,
            NtNavTopbarComponent,
            NtNavBreadcrumbsComponent,
        ],
        declarations: [
            NtNavSidebarComponent,
            NtNavTopbarComponent,
            NtNavBreadcrumbsComponent
        ],
        providers: [NtNavigationAdapter]
    })
], NtNavModule);

export { NT_NAV_CONFIG, NT_NAV_MENUS, NtNavModule, NtNavSidebarComponent, NtNavTopbarComponent, NtNavUrlTreeStrategy, NtNavigationAdapter, resolveTitle, NtNavController as ɵa, NtNavBreadcrumbsComponent as ɵb };
//# sourceMappingURL=navigation.js.map
