import { Subject, defer } from 'rxjs';
import { distinctUntilChanged, takeUntil, startWith } from 'rxjs/operators';
import { trigger, transition } from '@angular/animations';
import { Input, Output, Component, ViewEncapsulation, NgModule } from '@angular/core';
import { FormControl, ReactiveFormsModule } from '@angular/forms';
import { fadeIn, fadeOut } from '@ng-tangram/components/core';
import { CommonModule } from '@angular/common';
import { NtAutocompleteModule } from '@ng-tangram/components/autocomplete';
import { NtInputModule } from '@ng-tangram/components/input';

var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let NtSearchInputComponent = class NtSearchInputComponent {
    constructor() {
        this._destory = new Subject();
        this._keywordChange = new Subject();
        this._placeholder = '';
        this._prekeyword = '';
        this._inputing = false;
        this._keywordControl = new FormControl();
        this.search = defer(() => this._keywordChange.pipe(distinctUntilChanged(), takeUntil(this._destory)));
        this.input = defer(() => this._keywordControl.valueChanges.pipe(startWith(''), takeUntil(this._destory)));
    }
    get placeholder() { return this._placeholder; }
    set placeholder(value) {
        this._placeholder = value;
    }
    onEnter(event) {
        this._keywordChange.next(this._keywordControl.value);
        this._prekeyword = this._keywordControl.value;
    }
    onBlur() {
        this._inputing = false;
        this._keywordControl.setValue(this._prekeyword, { emitEvent: false });
    }
    clearKeyword(event) {
        this._keywordControl.setValue('');
        this.onEnter(event);
        event.stopPropagation();
    }
    onOptionSelected(change) {
        console.log(change);
        this._keywordChange.next(change.option.value);
        this._keywordControl.setValue(change.option.value, { emitEvent: false });
    }
};
__decorate([
    Input()
], NtSearchInputComponent.prototype, "placeholder", null);
__decorate([
    Output()
], NtSearchInputComponent.prototype, "search", void 0);
__decorate([
    Output()
], NtSearchInputComponent.prototype, "input", void 0);
NtSearchInputComponent = __decorate([
    Component({
        selector: 'nt-search-input',
        template: "<nt-input-group transparent=\"true\" ntAutocompleteOrigin #origin=\"ntAutocompleteOrigin\">\n  <nt-input-addon>\n    <span class=\"fas fa-search\"></span>\n  </nt-input-addon>\n  <input type=\"text\"\n    [placeholder]=\"placeholder\"\n    [formControl]=\"_keywordControl\"\n    [ntAutocomplete]=\"auto\"\n    [ntAutocompleteConnectedTo]=\"origin\"\n    (keyup.enter)=\"onEnter($event)\"\n    (blur)=\"onBlur()\"\n    (focus)=\"_inputing = true\">\n  <nt-input-addon class=\"nt-search-input-clear\"\n    [@fade]\n    (click)=\"clearKeyword($event)\"\n    *ngIf=\"!_inputing && _prekeyword\">\n    <span class=\"fas fa-times-circle\"></span>\n  </nt-input-addon>\n</nt-input-group>\n\n<nt-autocomplete #auto=\"ntAutocomplete\" (optionSelected)=\"onOptionSelected($event)\">\n  <ng-content select=\"nt-option\"></ng-content>\n</nt-autocomplete>\n",
        encapsulation: ViewEncapsulation.None,
        animations: [
            trigger('fade', [
                transition('void => *', fadeIn(.15)),
                transition('* => void', fadeOut(.15))
            ])
        ],
        host: {
            'class': 'nt-search-input'
        }
    })
], NtSearchInputComponent);

var __decorate$1 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let NtSearchInputModule = class NtSearchInputModule {
};
NtSearchInputModule = __decorate$1([
    NgModule({
        imports: [
            CommonModule,
            ReactiveFormsModule,
            NtInputModule,
            NtAutocompleteModule
        ],
        exports: [
            NtSearchInputComponent,
            NtInputModule,
            NtAutocompleteModule
        ],
        declarations: [
            NtSearchInputComponent
        ]
    })
], NtSearchInputModule);

export { NtSearchInputComponent, NtSearchInputModule };
//# sourceMappingURL=searchInput.js.map
