import { CommonModule } from '@angular/common';
import { Inject, Component, ViewEncapsulation, Injectable, NgModule } from '@angular/core';
import { NT_MODAL_DATA, NtModal, NtModalModule } from '@ng-tangram/components/modal';
import { NtSwitchModule } from '@ng-tangram/components/switch';
import { Subject } from 'rxjs';
import { takeUntil } from 'rxjs/operators';

var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var NtColumnSettingComponent = (function () {
    function NtColumnSettingComponent(data) {
        this.data = data;
        this._destroy = new Subject();
        this._displayedColumnChanges = new Subject();
        this.displayedColumns = [];
        this.columns = this.data.columns;
        this.columnNames = this.columns.map(function (col) { return col.name; });
        this.displayedColumns = this.data.displayedColumns;
    }
    NtColumnSettingComponent.prototype.ngOnDestroy = function () {
        this._destroy.next();
        this._destroy.complete();
    };
    NtColumnSettingComponent.prototype.displayedColumnChanges = function () {
        return this._displayedColumnChanges
            .asObservable()
            .pipe(takeUntil(this._destroy));
    };
    NtColumnSettingComponent.prototype._onChange = function (change, columnName) {
        var _this = this;
        if (change.checked) {
            this.displayedColumns.push(columnName);
        }
        else {
            var index = this.displayedColumns.indexOf(columnName);
            this.displayedColumns.splice(index, 1);
        }
        var sortedColumns = this.columnNames.filter(function (name) { return _this.displayedColumns.includes(name); });
        this._displayedColumnChanges.next(sortedColumns);
    };
    NtColumnSettingComponent.prototype._trackColumnChecked = function (columnName) {
        return this.displayedColumns.includes(columnName);
    };
    NtColumnSettingComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [NT_MODAL_DATA,] }] }
    ]; };
    NtColumnSettingComponent = __decorate([
        Component({
            template: "<nt-modal-header>\u6570\u636E\u5217\u663E\u793A\u8BBE\u7F6E</nt-modal-header>\n<nt-modal-body class=\"padding-0\">\n  <div class=\"nt-column-setting\">\n    <div class=\"nt-column-setting-menu\">\n      <div class=\"nt-column-setting-item\"\n        [class.disabled]=\"!col.optional\"\n        *ngFor=\"let col of columns\">\n        <a class=\"nt-column-setting-label\">{{ col.label }}</a>\n        <span class=\"nt-column-setting-control\">\n          <nt-switch class=\"nt-column-switch large\"\n            [checked]=\"_trackColumnChecked(col.name)\"\n            (change)=\"_onChange($event, col.name)\"\n            [disabled]=\"!col.optional\"\n            circle>\n          </nt-switch>\n        </span>\n      </div>\n    </div>\n  </div>\n</nt-modal-body>\n",
            encapsulation: ViewEncapsulation.None
        }),
        __param(0, Inject(NT_MODAL_DATA))
    ], NtColumnSettingComponent);
    return NtColumnSettingComponent;
}());

var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __decorate$1 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var MzColumnSetting = (function () {
    function MzColumnSetting(modal) {
        this.modal = modal;
        this._defaultModalConfig = {
            width: '460px',
            maxWidth: '90vw',
            maxHeight: '90vh',
            backdropClass: 'light-backdrop'
        };
    }
    MzColumnSetting.prototype.openAndTrackChanges = function (columns, displayedColumns) {
        var data = { columns: columns, displayedColumns: displayedColumns };
        var modalConfig = __assign(__assign({}, this._defaultModalConfig), { data: data });
        var modalRef = this.modal.open(NtColumnSettingComponent, modalConfig);
        return modalRef.componentInstance.displayedColumnChanges();
    };
    MzColumnSetting.ctorParameters = function () { return [
        { type: NtModal }
    ]; };
    MzColumnSetting = __decorate$1([
        Injectable()
    ], MzColumnSetting);
    return MzColumnSetting;
}());

var __decorate$2 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var NtColumnSettingModule = (function () {
    function NtColumnSettingModule() {
    }
    NtColumnSettingModule = __decorate$2([
        NgModule({
            imports: [
                CommonModule,
                NtModalModule,
                NtSwitchModule
            ],
            entryComponents: [NtColumnSettingComponent],
            declarations: [NtColumnSettingComponent],
            providers: [MzColumnSetting],
        })
    ], NtColumnSettingModule);
    return NtColumnSettingModule;
}());

export { MzColumnSetting, NtColumnSettingComponent, NtColumnSettingModule };
//# sourceMappingURL=columnController.js.map
