import { Subject, defer } from 'rxjs';
import { distinctUntilChanged, takeUntil, startWith } from 'rxjs/operators';
import { trigger, transition } from '@angular/animations';
import { Input, Output, Component, ViewEncapsulation, NgModule } from '@angular/core';
import { FormControl, ReactiveFormsModule } from '@angular/forms';
import { fadeIn, fadeOut } from '@ng-tangram/components/core';
import { CommonModule } from '@angular/common';
import { NtAutocompleteModule } from '@ng-tangram/components/autocomplete';
import { NtInputModule } from '@ng-tangram/components/input';

var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var NtSearchInputComponent = (function () {
    function NtSearchInputComponent() {
        var _this = this;
        this._destory = new Subject();
        this._keywordChange = new Subject();
        this._placeholder = '';
        this._prekeyword = '';
        this._inputing = false;
        this._keywordControl = new FormControl();
        this.search = defer(function () {
            return _this._keywordChange.pipe(distinctUntilChanged(), takeUntil(_this._destory));
        });
        this.input = defer(function () {
            return _this._keywordControl.valueChanges.pipe(startWith(''), takeUntil(_this._destory));
        });
    }
    Object.defineProperty(NtSearchInputComponent.prototype, "placeholder", {
        get: function () { return this._placeholder; },
        set: function (value) {
            this._placeholder = value;
        },
        enumerable: true,
        configurable: true
    });
    NtSearchInputComponent.prototype.onEnter = function (event) {
        this._keywordChange.next(this._keywordControl.value);
        this._prekeyword = this._keywordControl.value;
    };
    NtSearchInputComponent.prototype.onBlur = function () {
        this._inputing = false;
        this._keywordControl.setValue(this._prekeyword, { emitEvent: false });
    };
    NtSearchInputComponent.prototype.clearKeyword = function (event) {
        this._keywordControl.setValue('');
        this.onEnter(event);
        event.stopPropagation();
    };
    NtSearchInputComponent.prototype.onOptionSelected = function (change) {
        console.log(change);
        this._keywordChange.next(change.option.value);
        this._keywordControl.setValue(change.option.value, { emitEvent: false });
    };
    __decorate([
        Input()
    ], NtSearchInputComponent.prototype, "placeholder", null);
    __decorate([
        Output()
    ], NtSearchInputComponent.prototype, "search", void 0);
    __decorate([
        Output()
    ], NtSearchInputComponent.prototype, "input", void 0);
    NtSearchInputComponent = __decorate([
        Component({
            selector: 'nt-search-input',
            template: "<nt-input-group transparent=\"true\" ntAutocompleteOrigin #origin=\"ntAutocompleteOrigin\">\n  <nt-input-addon>\n    <span class=\"fas fa-search\"></span>\n  </nt-input-addon>\n  <input type=\"text\"\n    [placeholder]=\"placeholder\"\n    [formControl]=\"_keywordControl\"\n    [ntAutocomplete]=\"auto\"\n    [ntAutocompleteConnectedTo]=\"origin\"\n    (keyup.enter)=\"onEnter($event)\"\n    (blur)=\"onBlur()\"\n    (focus)=\"_inputing = true\">\n  <nt-input-addon class=\"nt-search-input-clear\"\n    [@fade]\n    (click)=\"clearKeyword($event)\"\n    *ngIf=\"!_inputing && _prekeyword\">\n    <span class=\"fas fa-times-circle\"></span>\n  </nt-input-addon>\n</nt-input-group>\n\n<nt-autocomplete #auto=\"ntAutocomplete\" (optionSelected)=\"onOptionSelected($event)\">\n  <ng-content select=\"nt-option\"></ng-content>\n</nt-autocomplete>\n",
            encapsulation: ViewEncapsulation.None,
            animations: [
                trigger('fade', [
                    transition('void => *', fadeIn(.15)),
                    transition('* => void', fadeOut(.15))
                ])
            ],
            host: {
                'class': 'nt-search-input'
            }
        })
    ], NtSearchInputComponent);
    return NtSearchInputComponent;
}());

var __decorate$1 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var NtSearchInputModule = (function () {
    function NtSearchInputModule() {
    }
    NtSearchInputModule = __decorate$1([
        NgModule({
            imports: [
                CommonModule,
                ReactiveFormsModule,
                NtInputModule,
                NtAutocompleteModule
            ],
            exports: [
                NtSearchInputComponent,
                NtInputModule,
                NtAutocompleteModule
            ],
            declarations: [
                NtSearchInputComponent
            ]
        })
    ], NtSearchInputModule);
    return NtSearchInputModule;
}());

export { NtSearchInputComponent, NtSearchInputModule };
//# sourceMappingURL=searchInput.js.map
