"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@angular-devkit/core");
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const angular_config_1 = require("../utils/angular-config");
const ast_1 = require("../utils/ast");
const package_config_1 = require("../utils/package-config");
const pkg = require('../../package.json');
const CORE_PACKAGES = [
    '@angular/cdk',
    '@ng-tangram/components'
];
const NGXS_PACKAGES = [
    '@ngxs/form-plugin',
    '@ngxs/logger-plugin',
    '@ngxs/router-plugin',
    '@ngxs/storage-plugin',
    '@ngxs/store'
];
function setupForceOptions(projectName) {
    return (tree) => {
        const config = angular_config_1.readConfig(tree);
        const appConfig = angular_config_1.getAngularAppConfig(config, projectName);
        const appSchematicsConfig = appConfig.schematics['@schematics/angular:component'];
        appConfig.schematics = Object.assign(Object.assign({}, appConfig.schematics), { '@schematics/angular:component': Object.assign(Object.assign({}, appSchematicsConfig), { style: 'scss' }) });
        angular_config_1.writeConfig(tree, config);
    };
}
function addTangramToPackageJson(modulePath) {
    return (tree) => {
        CORE_PACKAGES.forEach(name => {
            package_config_1.addPackageToDependenciesNode(tree, name, pkg.peerDependencies[name]);
        });
        // addPackageToDependenciesNode(tree, '@ng-tangram/pro', 'latest');
        package_config_1.addPackageToDependenciesNode(tree, 'faker', '^4.1.0');
        package_config_1.addPackageToDevDependenciesNode(tree, '@types/faker', '^4.1.11');
        ast_1.addModuleImportToModule(tree, modulePath, 'BrowserAnimationsModule', '@angular/platform-browser/animations');
        ast_1.addModuleImportToModule(tree, modulePath, 'HttpClientModule', '@angular/common/http');
        ast_1.addModuleImportToModule(tree, modulePath, 'NtNativeDateModule', '@ng-tangram/components/core');
        ast_1.addModuleImportToModule(tree, modulePath, 'NtNoopUploadModule', '@ng-tangram/components/noop-upload');
        ast_1.addModuleImportToModule(tree, modulePath, 'NtFormsModule.forRoot()', '@ng-tangram/components/forms');
        return tree;
    };
}
/** 增加 ngxs  */
function addNgxsToPackageJson(modulePath) {
    return (tree) => {
        // Add Dependencies
        NGXS_PACKAGES.forEach(pkg => {
            package_config_1.addPackageToDependenciesNode(tree, pkg, '^3.6.2');
        });
        // Add Development Dependencies
        ['@ngxs/devtools-plugin'].forEach(pkg => {
            package_config_1.addPackageToDevDependenciesNode(tree, pkg, '^3.6.2');
        });
        ast_1.addModuleImportToModule(tree, modulePath, `NgxsModule.forRoot([], { developmentMode: true })`, '@ngxs/store');
        ast_1.addModuleImportToModule(tree, modulePath, 'NgxsReduxDevtoolsPluginModule.forRoot()', '@ngxs/devtools-plugin');
        return tree;
    };
}
function addFontAwesomeToPackageJson(projectName) {
    return (tree) => {
        [
            "@fortawesome/angular-fontawesome",
            "@fortawesome/fontawesome-svg-core",
            "@fortawesome/fontawesome-free",
            "@fortawesome/free-brands-svg-icons",
            "@fortawesome/free-regular-svg-icons",
            "@fortawesome/free-solid-svg-icons"
        ].forEach(name => {
            package_config_1.addPackageToDependenciesNode(tree, name, pkg.peerDependencies[name]);
        });
        [
            "./node_modules/@fortawesome/fontawesome-free/css/fontawesome.min.css",
            "./node_modules/@fortawesome/fontawesome-free/css/solid.min.css",
            "./node_modules/@fortawesome/fontawesome-free/css/brands.min.css",
        ].forEach(style => {
            angular_config_1.addStyle(tree, projectName, style);
        });
        return tree;
    };
}
function addFoundationPackageToPackageJson() {
    return (tree) => {
        const name = 'foundation-sites';
        package_config_1.addPackageToDependenciesNode(tree, name, pkg.peerDependencies[name]);
        return tree;
    };
}
function default_1(options) {
    return (tree, context) => {
        const workspace = angular_config_1.getWorkspace(tree);
        if (!options.project) {
            options.project = angular_config_1.getDefaultAngularAppName(workspace);
        }
        const project = workspace.projects[options.project];
        if (project.projectType !== 'application') {
            throw new schematics_1.SchematicsException(`Add requires a project type of "application".`);
        }
        const sourcePath = core_1.join(project.sourceRoot);
        const rootTemplateSource = schematics_1.apply(schematics_1.url(`./files/`), [
            schematics_1.applyTemplates({
                classify: core_1.strings.classify,
                dasherize: core_1.strings.dasherize,
            }),
            schematics_1.move(sourcePath)
        ]);
        const modulePath = ast_1.findModuleFromOptions(tree, options);
        const mergedRules = [
            setupForceOptions(options.project),
            addFoundationPackageToPackageJson(),
            addTangramToPackageJson(modulePath),
            addNgxsToPackageJson(modulePath),
            addFontAwesomeToPackageJson(options.project),
            schematics_1.mergeWith(rootTemplateSource, schematics_1.MergeStrategy.Overwrite),
        ];
        if (!options.skipInstall) {
            context.addTask(new tasks_1.NodePackageInstallTask());
        }
        return schematics_1.chain(mergedRules);
    };
}
exports.default = default_1;
//# sourceMappingURL=index.js.map